@@ -21,11 +21,11 @@
 #include <string.h>
 #include "core/array.h"
 #include "core/assert_api.h"
-#include "core/compat.h"
+#include "core/compat_api.h"
 #include "core/cstr_api.h"
-#include "core/hashmap.h"
-#include "core/ma.h"
-#include "core/md5_seqid.h"
+#include "core/hashmap_api.h"
+#include "core/ma_api.h"
+#include "core/md5_seqid_api.h"
 #include "core/parseutils.h"
 #include "core/queue.h"
 #include "core/splitter.h"
@@ -37,11 +37,11 @@
 #include "extended/feature_info.h"
 #include "extended/feature_node.h"
 #include "extended/feature_node_iterator_api.h"
-#include "extended/feature_type.h"
+#include "extended/feature_type_api.h"
 #include "extended/gap_str.h"
 #include "extended/genome_node.h"
 #include "extended/gff3_defines.h"
-#include "extended/gff3_escaping.h"
+#include "extended/gff3_escaping_api.h"
 #include "extended/gff3_parser.h"
 #include "extended/mapping.h"
 #include "extended/orphanage.h"
