@@ -17,18 +17,18 @@
 */
 
 #include "core/alphabet_api.h"
-#include "core/arraydef.h"
+#include "core/arraydef_api.h"
 #include "core/bittab_api.h"
 #include "core/codetype.h"
 #include "core/encseq_api.h"
-#include "core/ensure.h"
+#include "core/ensure_api.h"
 #include "core/error_api.h"
 #include "core/intbits.h"
 #include "core/log_api.h"
 #include "core/logger.h"
-#include "core/ma.h"
 #include "core/ma_api.h"
-#include "core/mathsupport.h"
+#include "core/ma_api.h"
+#include "core/mathsupport_api.h"
 #include "core/radix_sort.h"
 #include "core/range_api.h"
 #include "core/types_api.h"
