@@ -27,16 +27,16 @@
 #include "lua-lpeg.h"
 #include "md5.h"
 #include "ldes56.h"
-#include "core/compat.h"
+#include "core/compat_api.h"
 #include "core/cstr.h"
-#include "core/cstr_array.h"
-#include "core/ensure.h"
-#include "core/fa.h"
+#include "core/cstr_array_api.h"
+#include "core/ensure_api.h"
+#include "core/fa_api.h"
 #include "core/fileutils_api.h"
 #include "core/gtdatapath.h"
 #include "core/log.h"
 #include "core/warning_api.h"
-#include "core/ma.h"
+#include "core/ma_api.h"
 #include "core/multithread_api.h"
 #include "core/option.h"
 #include "core/parseutils.h"
@@ -44,11 +44,11 @@
 #include "core/toolbox.h"
 #include "core/tool_iterator.h"
 #include "core/types_api.h"
-#include "core/unit_testing.h"
-#include "core/versionfunc.h"
+#include "core/unit_testing_api.h"
+#include "core/versionfunc_api.h"
 #include "core/xansi_api.h"
-#include "core/xposix.h"
-#include "core/yarandom.h"
+#include "core/xposix_api.h"
+#include "core/yarandom_api.h"
 #include "extended/gtdatahelp.h"
 #include "extended/luahelper.h"
 #include "gtlua/gt_lua.h"
