@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008-2015 Sascha Steinbiss <sascha@steinbiss.name>
+  Copyright (c) 2008-2020 Sascha Steinbiss <sascha@steinbiss.name>
   Copyright (c) 2008-2013 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -22,17 +22,18 @@
 #include <stdio.h>
 #include <string.h>
 #include "core/class_alloc_lock.h"
-#include "core/compat.h"
+#include "core/compat_api.h"
 #include "core/cstr_api.h"
-#include "core/fasta.h"
-#include "core/hashmap.h"
-#include "core/ma.h"
-#include "core/minmax.h"
-#include "core/range.h"
-#include "core/str.h"
+#include "core/fasta_api.h"
+#include "core/hashmap_api.h"
+#include "core/ma_api.h"
+#include "core/minmax_api.h"
+#include "core/range_api.h"
+#include "core/str_api.h"
 #include "core/symbol.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
+#include "core/warning_api.h"
 #include "extended/extract_feature_sequence.h"
 #include "extended/feature_node.h"
 #include "extended/feature_node_iterator_api.h"
@@ -114,7 +115,8 @@ static int gt_ltrelement_format_description(GtLTRElement *e,
   char tmpstr[BUFSIZ];
   gt_assert(buf && e);
 
-  (void) snprintf(tmpstr, MIN(BUFSIZ, (size_t) seqnamelen+1), "%s", e->seqid);
+  (void) snprintf(tmpstr, GT_MIN(BUFSIZ, (size_t) seqnamelen+1), "%s",
+                  e->seqid);
   tmpstr[seqnamelen+1] = '\0';
   gt_cstr_rep(tmpstr, ' ', '_');
   ret = snprintf(buf, buflen, "%s_"GT_WU"_"GT_WU"", tmpstr, e->leftLTR_5+1,
@@ -415,19 +417,24 @@ int gt_ltrfileout_stream_next(GtNodeStream *ns, GtGenomeNode **gn, GtError *err)
 
     if (!had_err) {
       GtRange rng;
+      int ret = 0;
+
       ls->element.seqid = gt_calloc((size_t) ls->seqnamelen+1, sizeof (char));
       (void) snprintf(ls->element.seqid,
-                      MIN((size_t) gt_str_length(sdesc),
+                      GT_MIN((size_t) gt_str_length(sdesc),
                           (size_t) ls->seqnamelen)+1,
                       "%s", gt_str_get(sdesc));
       gt_cstr_rep(ls->element.seqid, ' ', '_');
       if (gt_str_length(sdesc) > (GtUword) ls->seqnamelen)
         ls->element.seqid[ls->seqnamelen] = '\0';
 
-      (void) gt_ltrelement_format_description(&ls->element,
-                                              ls->seqnamelen,
-                                              desc,
-                                              (size_t) (GT_MAXFASTAHEADER-1));
+      ret = gt_ltrelement_format_description(&ls->element,
+                                             ls->seqnamelen,
+                                             desc,
+                                             (size_t) (GT_MAXFASTAHEADER-1));
+      if (ret < 0) {
+        gt_warning("FASTA header truncated: %s", desc);
+      }
       gt_str_delete(sdesc);
 
       /* output basic retrotransposon data */
