@@ -21,11 +21,11 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "core/fa.h"
-#include "core/fileutils.h"
+#include "core/fa_api.h"
+#include "core/fileutils_api.h"
 #include "core/array.h"
 #include "core/endianess_api.h"
-#include "core/error.h"
+#include "core/error_api.h"
 #include "core/ma_api.h"
 #include "core/format64.h"
 #include "core/codetype.h"
@@ -48,7 +48,7 @@
           (STREAM)->nextfree = 0;\
           (STREAM)->bufferedfilespace\
             = gt_malloc(sizeof *((STREAM)->bufferedfilespace)\
-                        * (FILEBUFFERSIZE));\
+                        * (GT_FILEBUFFERSIZE));\
         }
 
 static int scanprjfileuintkeysviafileptr(Suffixarray *suffixarray,
