@@ -5,10 +5,10 @@
 #include <math.h>
 #include <ctype.h>
 #include "core/assert_api.h"
-#include "core/arraydef.h"
-#include "core/minmax.h"
-#include "core/chardef.h"
-#include "core/divmodmul.h"
+#include "core/arraydef_api.h"
+#include "core/minmax_api.h"
+#include "core/chardef_api.h"
+#include "core/divmodmul_api.h"
 #include "core/readmode.h"
 #include "match/ft-polish.h"
 #include "match/ft-eoplist.h"
@@ -605,7 +605,7 @@ void gt_eoplist_trace2cigar(GtEoplist *eoplist,bool dtrace,GtUword trace_delta)
       aligned_v = (GtUword) eoplist->trace.spaceint[idx];
     }
     gt_assert(offset_u < eoplist->ulen);
-    aligned_u = MIN(trace_delta,eoplist->ulen - offset_u);
+    aligned_u = GT_MIN(trace_delta,eoplist->ulen - offset_u);
     this_distance = gt_full_front_edist_trace_distance(eoplist->fet_segment,
                                                        eoplist->useq + offset_u,
                                                        aligned_u,
@@ -823,7 +823,7 @@ void gt_eoplist_set_sequences(GtEoplist *eoplist,
 static int gt_eoplist_numwidth(const GtEoplist *eoplist)
 {
   gt_assert(eoplist != NULL);
-  return 1 + log10((double) MAX(eoplist->ustart + eoplist->ulen - 1,
+  return 1 + log10((double) GT_MAX(eoplist->ustart + eoplist->ulen - 1,
                                 eoplist->vstart + eoplist->vlen - 1));
 }
 
@@ -894,7 +894,7 @@ void gt_eoplist_format_generic(FILE *fp,
           }
           if (characters != NULL)
           {
-            if (ISSPECIAL(cc_a))
+            if (GT_ISSPECIAL(cc_a))
             {
               cc_a = wildcardshow;
               is_match = false;
@@ -907,7 +907,7 @@ void gt_eoplist_format_generic(FILE *fp,
               }
               cc_a = characters[cc_a];
             }
-            if (ISSPECIAL(cc_b))
+            if (GT_ISSPECIAL(cc_b))
             {
               cc_b = wildcardshow;
               is_match = false;
@@ -984,7 +984,7 @@ void gt_eoplist_format_generic(FILE *fp,
                                                       : eoplist->ulen-1-idx_u];
           if (characters != NULL)
           {
-            if (ISSPECIAL(cc_a))
+            if (GT_ISSPECIAL(cc_a))
             {
               topbuf[pos] = wildcardshow;
             } else
@@ -1035,7 +1035,7 @@ void gt_eoplist_format_generic(FILE *fp,
           midbuf[pos] = EOPLIST_MISMATCHSYMBOL;
           if (characters != NULL)
           {
-            if (ISSPECIAL(cc_b))
+            if (GT_ISSPECIAL(cc_b))
             {
               lowbuf[pos] = wildcardshow;
             } else
@@ -1090,11 +1090,11 @@ void gt_eoplist_format_generic(FILE *fp,
                            topbuf,
                            top_seqlength,
                            top_start_pos,
-                           eoplist->ustart + MIN(idx_u,eoplist->ulen - 1),
+                           eoplist->ustart + GT_MIN(idx_u,eoplist->ulen - 1),
                            midbuf,
                            lowbuf,
                            low_start_pos,
-                           low_start_base + MIN(idx_v,eoplist->vlen - 1),
+                           low_start_base + GT_MIN(idx_v,eoplist->vlen - 1),
                            fp);
   }
   if (eoplist->pol_info != NULL && eoplist->pol_info_out)
@@ -1182,7 +1182,7 @@ void gt_eoplist_format_exact(FILE *fp,
                                              : low_reference - eoplist->vstart;
 
   gt_assert(alignment_show_forward || top_seqlength > 0);
-  width = MIN(eoplist->ulen, eoplist_reader->width);
+  width = GT_MIN(eoplist->ulen, eoplist_reader->width);
   midbuf = topbuf + width;
   for (idx = 0; idx < (GtUword) width; idx++)
   {
@@ -1231,11 +1231,11 @@ void gt_eoplist_format_exact(FILE *fp,
                            topbuf,
                            top_seqlength,
                            top_start_pos,
-                           eoplist->ustart + MIN(idx,eoplist->ulen - 1),
+                           eoplist->ustart + GT_MIN(idx,eoplist->ulen - 1),
                            midbuf,
                            lowbuf,
                            low_start_pos,
-                           eoplist->vstart + MIN(idx,eoplist->vlen - 1),
+                           eoplist->vstart + GT_MIN(idx,eoplist->vlen - 1),
                            fp);
   }
 }
@@ -1284,7 +1284,7 @@ void gt_eoplist_verify(const GtEoplist *eoplist,
           {
             const GtUchar a = eoplist->useq[sumulen+idx],
                           b = eoplist->vseq[sumvlen+idx];
-            if (a == b && !ISSPECIAL(a))
+            if (a == b && !GT_ISSPECIAL(a))
             {
               gt_assert(co.eoptype == GtMatchOp);
             } else
@@ -1292,7 +1292,7 @@ void gt_eoplist_verify(const GtEoplist *eoplist,
               gt_assert(!distinguish_mismatch_match ||
                         co.eoptype == GtMismatchOp);
             }
-            if (!distinguish_mismatch_match && (a != b || ISSPECIAL(a)))
+            if (!distinguish_mismatch_match && (a != b || GT_ISSPECIAL(a)))
             {
               sumdist++;
             }
