@@ -19,7 +19,7 @@
 #define QGRAM2CODE_H
 
 #include "core/types_api.h"
-#include "core/chardef.h"
+#include "core/chardef_api.h"
 #include "core/codetype.h"
 
 static inline unsigned int qgram2code(GtCodetype *code,
@@ -34,7 +34,7 @@ static inline unsigned int qgram2code(GtCodetype *code,
   for (i=(int) (qvalue-1); i>=0; i--)
   {
     a = qgram[i];
-    if (ISSPECIAL(a))
+    if (GT_ISSPECIAL(a))
     {
       return (unsigned int) i;
     }
