@@ -18,8 +18,8 @@
 #include "core/encseq.h"
 #include "core/log_api.h"
 #include "core/logger.h"
-#include "core/fa.h"
-#include "core/ma.h"
+#include "core/fa_api.h"
+#include "core/ma_api.h"
 #include "core/unused_api.h"
 #include "core/showtime.h"
 #include "core/spacecalc.h"
@@ -148,6 +148,7 @@ static int gt_readjoiner_asqg_use_spmfiles(GtSpmproc proc, void *procdata,
     skipdata.to_skip = contained;
     skipdata.out.e.proc = proc;
     skipdata.out.e.data = procdata;
+    skipdata.skipped_counter = 0;
   }
   for (i = 0; i < nspmfiles; i++)
   {
